@@ -82,12 +82,6 @@ public:
    *
    * The initial model is \c 0.
    *
-   * \if cpp
-   * Ownership of the model is not transferred (and thus the
-   * previously set model is not deleted). A model may not be deleted as
-   * long as a view exists for it.
-   * \endif
-   *
    * \sa setRootIndex()
    */
   virtual void setModel(const std::shared_ptr<WAbstractItemModel>& model);
@@ -714,9 +708,37 @@ public:
    *
    * When the event happened over an item, the first argument
    * indicates the item that was touched.
+   *
+   * \deprecated Use touchStarted() instead.
    */
   Signal<WModelIndex, WTouchEvent>& touchStart() { return touchStart_; }
 
+  /*! \brief %Signal emitted when one or more fingers are placed on the screen.
+   *
+   * When the event happened over an item, the first argument
+   * indicates the items that were touched. The indices in the model index
+   * vector match the indices in the \link WTouchEvent::changedTouches() changedTouches() of the WTouchEvent\endlink.
+   */
+  Signal<std::vector<WModelIndex>, WTouchEvent>& touchStarted() { return touchStarted_; }
+
+  /*! \brief %Signal emitted when one or more fingers are moved on the screen.
+   *
+   * When the event happened over an item, the first argument
+   * indicates the items that were touched. The indices in the model index
+   * vector match the indices in the \link WTouchEvent::changedTouches() changedTouches() of the WTouchEvent\endlink.
+   */
+  Signal<std::vector<WModelIndex>, WTouchEvent>& touchMoved() { return touchMoved_; }
+
+  /*! \brief %Signal emitted when one or more fingers are removed from the screen.
+   *
+   * When the event happened over an item, the first argument
+   * indicates the items where the touch ended. The indices in the model index
+   * vector match the indices in the \link WTouchEvent::changedTouches() changedTouches() of the WTouchEvent\endlink.
+   *
+   * \note When JavaScript is disabled, the signal will never fire.
+   */
+  Signal<std::vector<WModelIndex>, WTouchEvent>& touchEnded() { return touchEnded_; }
+
   /*! \brief %Signal emitted when the selection is changed.
    *
    * \sa select(), setSelectionMode(), setSelectionBehavior()
@@ -946,6 +968,7 @@ protected:
   int currentSortColumn_;
 
   bool dragEnabled_, dropsEnabled_;
+  std::unique_ptr<WWidget> uDragWidget_;
   observing_ptr<WWidget> dragWidget_;
 
   virtual void scheduleRerender(RenderState what);
@@ -1007,13 +1030,30 @@ protected:
   virtual void handleMouseUp(const WModelIndex& index,
 			     const WMouseEvent& event);
 
+  /*! \brief Handles a touch select event.
+   */
+  virtual void handleTouchSelect(const std::vector<WModelIndex>& indices,
+				 const WTouchEvent& event);
+
   /*! \brief Handles a touch started event.
    */
   virtual void handleTouchStart(const std::vector<WModelIndex>& indices,
-				       const WTouchEvent& event);
+				const WTouchEvent& event);
+
+  /*! \brief Handles a touch moved event.
+   */
+  virtual void handleTouchMove(const std::vector<WModelIndex>& indices,
+                               const WTouchEvent& event);
+
+  /*! \brief Handles a touch ended event.
+   */
+  virtual void handleTouchEnd(const std::vector<WModelIndex>& indices,
+			      const WTouchEvent& event);
 
   virtual bool internalSelect(const WModelIndex& index, SelectionFlag option);
 
+  virtual void enableAjax() override;
+
   void setEditState(const WModelIndex& index, const cpp17::any& editState);
   cpp17::any editState(const WModelIndex& index) const;
   bool hasEditFocus(const WModelIndex& index) const;
@@ -1080,6 +1120,9 @@ private:
   Signal<WModelIndex, WMouseEvent> mouseWentDown_;
   Signal<WModelIndex, WMouseEvent> mouseWentUp_;
   Signal<WModelIndex, WTouchEvent> touchStart_;
+  Signal<std::vector<WModelIndex>, WTouchEvent> touchStarted_;
+  Signal<std::vector<WModelIndex>, WTouchEvent> touchMoved_;
+  Signal<std::vector<WModelIndex>, WTouchEvent> touchEnded_;
   Signal<> selectionChanged_;
   Signal<> pageChanged_;
 
